// -*- C++ -*-
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: cons_storebool.h 267 2012-07-21 16:45:56Z pfetsch $"

/**@file   cons_storebool.h
 * @brief  constraint handler for storing a bool at each node of the tree
 * @author Marc Pfetsch
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __SCIP_CONS_STOREBOOL_H_
#define __SCIP_CONS_STOREBOOL_H_

#include <scip/scip.h>

#ifdef __cplusplus
extern "C" {
#endif

/** get size of stack */
unsigned int getNodeDataStackSize(
   SCIP_CONSHDLR*        conshdlr            /**< store bool constraint handler */
   );

/** get node data of current node */
extern
SCIP_Bool getNodeData(
   SCIP_CONSHDLR*        conshdlr            /**< store bool constraint handler */
   );

/** set node data of current node */
extern
void setNodeData(
   SCIP_CONSHDLR*        conshdlr,           /**< store bool constraint handler */
   SCIP_Bool             data                /**< bool to store */
   );

/** creates and captures an order storing constraint */
extern
SCIP_RETCODE createConsStorebool(
   SCIP*                 scip,               /**< SCIP data structure */
   SCIP_CONS**           cons,               /**< pointer to hold the created constraint */
   const char*           name,               /**< name of constraint */
   SCIP_Bool             data                /**< bool to store in node */
   );

/** include store bool constraint handler */
extern
SCIP_RETCODE SCIPincludeConshdlrStorebool(
   SCIP*                 scip                /**< SCIP data structure */
   );

#ifdef __cplusplus
}
#endif

#endif
