/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: cons_subtreebool.h 267 2012-07-21 16:45:56Z pfetsch $"

/**@file   cons_subtreebool.h
 * @brief  constraint handler for storing a bool for subtrees
 * @author Marc Pfetsch
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __SCIP_CONS_SUBTREEBOOL_H_
#define __SCIP_CONS_SUBTREEBOOL_H_

#include <scip/scip.h>

#ifdef __cplusplus
extern "C" {
#endif

/** determine whether bool is set for current subtree */
extern
SCIP_Bool SUBTREEgetBool(
   SCIP_CONSHDLR*        conshdlr            /**< subtree bool constraint handler */
   );

/** set value for current subtree to true */
extern
SCIP_RETCODE SUBTREEsetTrue(
   SCIP*                 scip,               /**< SCIP data structure */
   SCIP_CONSHDLR*        conshdlr            /**< subtree bool constraint handler */
   );

/** include subtree bool constraint handler */
extern
SCIP_RETCODE SCIPincludeConshdlrSubtreebool(
   SCIP*                 scip                /**< SCIP data structure */
   );

#ifdef __cplusplus
}
#endif

#endif
