// -*- C++ -*-
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: graph.h 1215 2015-10-27 10:03:07Z pfetsch $"

/**@file   graph.h
 * @brief  BOOST data structure definitions
 * @author Marc Pfetsch
 */


#ifndef GRAPH_H
#define GRAPH_H

// turn of warning for boost (just for this file)
#pragma GCC diagnostic ignored "-Wshadow"


#include <boost/graph/graph_traits.hpp>
#include <boost/graph/adjacency_list.hpp>


// -------------------------------------------------------------------------------
// ------------------------- Graph ----------------------------------------------
// -------------------------------------------------------------------------------

typedef boost::property<boost::vertex_color_t, int> VertexGraphColorProperty;
typedef boost::property<boost::edge_weight_t, double> EdgeWeightProperty;



/**@class Graph
 * @brief an undirected graph
 */
typedef boost::adjacency_list<boost::listS, boost::vecS, boost::undirectedS, VertexGraphColorProperty, EdgeWeightProperty > Graph;


// useful typedefs
typedef boost::graph_traits<Graph>::vertex_descriptor Vertex;
typedef boost::graph_traits<Graph>::edge_descriptor   Edge;
typedef boost::graph_traits<Graph>::vertex_iterator VertexIterator;
typedef boost::graph_traits<Graph>::edge_iterator EdgeIterator;
typedef boost::graph_traits<Graph>::out_edge_iterator OutEdgeIterator;
typedef boost::graph_traits<Graph>::adjacency_iterator AdjacencyIterator;

#pragma GCC diagnostic warning "-Wshadow"

#endif
