/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: handle_symmetries.h 1045 2015-10-18 11:53:09Z pfetsch $"

/**@file   handle_symmetries.h
 * @brief  Code needed to handle symmetries, e.g., detection
 * @author Marc Pfetsch
 * @author Thomas Rehn
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __SCIP_HANDLE_SYMMETRIES_H__
#define __SCIP_HANDLE_SYMMETRIES_H__

#include <scip/scip.h>

#ifdef __cplusplus
extern "C" {
#endif

/** Compute symmetry group of global binary MIP */
extern
SCIP_RETCODE computeSymmetry(
   SCIP*                 scip,               /**< SCIP pointer */
   unsigned int          maxgenerators,      /**< maximal number of generators constructed (= 0 if unlimited) */
   SCIP_Bool             uselayeredgraph,    /**< use layered graph for symmetry detection */
   int                   fixedtype,          /**< variable types that must be fixed by symmetries */
   SCIP_Bool             local,              /**< Use local variable bounds? */
   SCIP_VAR***           permvars,           /**< variables on which permutations act */
   unsigned int*         npermvars,          /**< number of variables */
   unsigned int***       perms,              /**< permutations */
   unsigned int*         nperms,             /**< number of permutations */
   unsigned int*         nmaxperms,          /**< maximal number of permutations (needed for freeing storage) */
   unsigned int**        baseindices,        /**< indices of variables that form a base for the strong generating set of permutations */
   unsigned int*         nbaseindices,       /**< number of base variables */
   unsigned int*         nbases              /**< number of bases */
   );

/** Compute a subgroup of the symmetry group of global MIP by transposition heuristics */
extern
SCIP_RETCODE computeSymmetryByHeuristic(
   SCIP*                 scip,               /**< SCIP pointer */
   SCIP_Bool             uselayeredgraph,    /**< use layered graph for symmetry detection */
   int                   fixedtype,          /**< variable types that must be fixed by symmetries */
   SCIP_Bool             local,              /**< Use local variable bounds? */
   SCIP_VAR***           permvars,           /**< variables on which permutations act */
   unsigned int*         npermvars,          /**< number of variables */
   unsigned int**        orbits,             /**< indices of variables moved by a symmetric group; variables of the same orbit are grouped together in this list */
   unsigned int*         norbits,            /**< number of entries in array orbits */
   unsigned int**        orbitsizes,         /**< list of orbit sizes into which the entries in the array orbits are grouped */
   unsigned int*         norbitsizes         /**< number of entries in array orbitsizes */
   );

#ifdef __cplusplus
}
#endif

#endif
