/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: orbital_fixing.h 1048 2015-10-18 12:06:36Z pfetsch $"

/**@file   orbital_fixing.h
 * @brief  methods to perform orbital fixing
 * @author Marc Pfetsch
 * @author Thomas Rehn
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __ORBITAL_FIXING_H_
#define __ORBITAL_FIXING_H_

#include <scip/scip.h>

#include <boost/shared_ptr.hpp>
#include <permlib/abstract_permutation_group.h>

/* useful defines */
typedef boost::shared_ptr<permlib::AbstractPermutationGroup> PermGroupPtr;


/** perform orbital fixing */
SCIP_RETCODE orbitalFixing(
   SCIP*                 scip,               /**< SCIP pointer */
   SCIP_VAR**            vars,               /**< variables */
   int                   nvars,              /**< number of variables */
   const PermGroupPtr&   group,              /**< local symmetry group or stabilizer of binary variables branched to 1 */
   SCIP_Bool&            infeasible,         /**< whether we detected that the problem is infeasible */
   unsigned int&         nfixedone,          /**< number of variables fixed to 1 */
   unsigned int&         ngen                /**< number of domain propagations performed */
   );

#endif
