/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: presol_orbitprobing.cpp 60 2011-07-10 08:55:22Z pfetsch $"

/**@file   presol_orbitprobing.h
 * @brief  presolver for orbit probing
 * @author Marc Pfetsch
 * @author Thomas Rehn
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __SCIP_PRESOL_ORBITPROBING_H__
#define __SCIP_PRESOL_ORBITPROBING_H__

#include "scip/scip.h"
#include <vector>

#ifdef __cplusplus
extern "C" {
#endif

/** creates the orbit probing presolver and includes it in SCIP */
extern
SCIP_RETCODE SCIPincludePresolOrbitprobing(
   SCIP*                 scip                /**< SCIP data structure */
   );

/** get number of variables fixed to 0 by orbit probing */
extern
std::size_t SCIPorbitprobingGetNFixedZero(
   SCIP*                 scip,               /**< SCIP data structure */
   SCIP_PRESOL*          presol              /**< orbit probing presolver */
   );

/** get array of variables fixed to 0 by orbit probing */
extern
std::vector<unsigned int>& SCIPorbitprobingGetFixedZero(
   SCIP*                 scip,               /**< SCIP data structure */
   SCIP_PRESOL*          presol              /**< orbit probing presolver */
   );

/** get number of variables fixed to 1 by orbit probing */
extern
std::size_t SCIPorbitprobingGetNFixedOne(
   SCIP*                 scip,               /**< SCIP data structure */
   SCIP_PRESOL*          presol              /**< orbit probing presolver */
   );

/** get array of variables fixed to 1 by orbit probing */
extern
const std::vector<unsigned int>& SCIPorbitprobingGetFixedOne(
   SCIP*                 scip,               /**< SCIP data structure */
   SCIP_PRESOL*          presol              /**< orbit probing presolver */
   );

#ifdef __cplusplus
}
#endif

#endif
