/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: presol_symbreak.cpp 60 2011-07-10 08:55:22Z pfetsch $"

/**@file   presol_symbreakheur.h
 * @brief  presolver for adding symmetry breaking constraints after heuristic symmetry detection
 * @author Marc Pfetsch
 * @author Thomas Rehn
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __SCIP_PRESOL_SYMBREAKHEUR_H__
#define __SCIP_PRESOL_SYMBREAKHEUR_H__

#include "scip/scip.h"

#ifdef __cplusplus
extern "C" {
#endif

/** creates the symmetry breaking presolver and includes it in SCIP */
extern
SCIP_RETCODE SCIPincludePresolSymbreakheur(
   SCIP*                 scip                /**< SCIP data structure */
   );

extern
/** sets symmetry information for symmetry breaking presolver */
SCIP_RETCODE SCIPsetPermsSymbreakheur(
   SCIP*                 scip,               /**< SCIP data structure */
   unsigned int          nvars,              /**< number of variables in the constraint */
   SCIP_VAR**            vars,               /**< array with variables for which isomorphism pruning is responsible */
   unsigned int*         orbits,             /**< orbits */
   unsigned int          norbits,            /**< number of orbits */
   unsigned int*         orbitsizes,         /**< sizes of each orbit */
   unsigned int          norbitsizes         /**< number of orbit sizes */
   );

#ifdef __cplusplus
}
#endif

#endif
