// -*- C++ -*-
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2015  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
#pragma ident "@(#) $Id: cons_symmetries.h 267 2012-07-21 16:45:56Z pfetsch $"

/**@file   type_probspec.h
 * @brief  type specification of problems
 * @author Marc Pfetsch
 * @author Thomas Rehn
 */

/*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

#ifndef __SCIP_TYPE_PROBSPEC_H_
#define __SCIP_TYPE_PROBSPEC_H_

#ifdef __cplusplus
extern "C" {
#endif

/** problem type specification */
enum SCIP_ProbSpec
{
   SCIP_PROBSPEC_INTEGER = 1,                /**< need symmetries for integer variables only */
   SCIP_PROBSPEC_BINARY  = 2,                /**< need symmetries for binary variables only */
   SCIP_PROBSPEC_REAL    = 4                 /**< need symmetries also for continuous variables */
};

typedef enum SCIP_ProbSpec SCIP_PROBSPEC;


/** determines whether variable should be fixed by permutations */
inline bool SymmetryFixVar(
   int                   fixedtype,          /**< bitset of variable types that should be fixed */
   SCIP_VAR*             var                 /**< variable to be considered */
   )
{
   if ( (fixedtype & (int) SCIP_PROBSPEC_INTEGER) && SCIPvarGetType(var) == SCIP_VARTYPE_INTEGER )
      return true;
   if ( (fixedtype & (int) SCIP_PROBSPEC_BINARY) && SCIPvarGetType(var) == SCIP_VARTYPE_BINARY )
      return true;
   if ( (fixedtype & (int) SCIP_PROBSPEC_REAL) &&
      (SCIPvarGetType(var) == SCIP_VARTYPE_CONTINUOUS || SCIPvarGetType(var) == SCIP_VARTYPE_IMPLINT) )
      return true;
   return false;
}


#ifdef __cplusplus
}
#endif

#endif
