/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*    This file is part of "mipsymmetries" a collection of                   */
/*    symmetry handling methods.                                             */
/*                                                                           */
/*    Copyright (C) 2010-2012  Marc Pfetsch, Thomas Rehn                     */
/*                                                                           */
/*                                                                           */
/*    Based on SCIP  --- Solving Constraint Integer Programs                 */
/*       SCIP is distributed under the terms of the SCIP Academic Licence,   */
/*       see file COPYING in the SCIP distribution.                          */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/**@file   xternal.c
 * @brief  main document page
 * @author Marc Pfetsch
 * @author Thomas Rehn
 */

/*--+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/

/**@mainpage Overview of package "mipsymmetries"
 *
 * @section INTRODUCTION Introduction
 *
 * This program package contains code for handling symmetries in mixed integer programs (MIP). I has been written by
 * Marc Pfetsch and Thomas Rehn. The implementations are based on articles in the literature. The package contains
 * - an implementation of "isomorophism pruning" as described by Margot:@n
 *    - F. Margot: Pruning by isomorphism in branch-and-cut@n
 *      Math. Progrm. 94, No. 1, 71-90 (2002)@n
 *    - F. Margot: Exploiting orbits in symmetric ILP@n
 *      Math. Program. 98, 3-21 (2003).@n
 *    - F. Margot: Symmetry in integer linear programming@n
 *      in: M. Juenger, T. Liebling, D. Naddef, G.L. Nemhauser, W. Pulleyblank, G. Reinelt, G. Rinaldi, L. Wolsey (Eds.),@n
 *      50 Years of Integer Programming 1958-2008, Springer-Verlag, Berlin, Heidelberg, 2010, pp. 647-681. (Chapter 17)
 * - an implementation of "orbital branching" as described@n
 *    - J. Ostrowski, J. Linderoth, F. Rossi, and S. Smriglio: Orbital branching,@n
 *      Mathematical Programming 126, No 1, pp. 147-178 (2011)
 *
 * - a presolving method that detects several substructures that can be (partly) handled by symmetry breaking constraints.
 *
 * Related to the first two points is "orbital fixing", which is implemented as a separate function as well.
 *
 * The symmetry handling parts are based on <A HREF="http://www.math.uni-rostock.de/~rehn/software/permlib.html">PERMLIB</A> a C++ library written by Thomas Rehn.
 *
 * The computation of symmetries is based on graph automorphisms, which we compute using the package
 * <A HREF="http://www.tcs.hut.fi/Software/bliss/">bliss</A>.
 *
 *
 * @section IMPLEMENTATION Implementation Details
 *
 * For the implementation we made several restricting decisions:
 *
 * - We only implement isomorphism pruning and orbital branching for binary variables. General integral variables cannot
 *   currently be handled. For isomorphism pruning, Margot describes a generalization that has not yet been
 *   implemented. For orbital branching, a generalization is possible, but is likely to be ineffective.
 *
 *
 * @todo Implement integer version of isomorphism pruning.
 *
 * @todo Check disabling of components. Only turn them off, if the symmetry has been computed before presolving.
 */
